@@ -25,7 +25,7 @@ IPC::Run::Debug - debugging routines for IPC::Run
 =head1 DESCRIPTION
 
 Controls IPC::Run debugging.  Debugging levels are now set by using words,
-but the numbers shown are still supported for backwards compatibility:
+but the numbers shown are still supported for backwards compatability:
 
    0  none         disabled (special, see below)
    1  basic        what's running
@@ -69,35 +69,37 @@ Both of those are untested.
 use strict;
 use Exporter;
 use vars qw{$VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS};
-
 BEGIN {
-    $VERSION = '0.94_02';
-    @ISA     = qw( Exporter );
-    @EXPORT  = qw(
-      _debug
-      _debug_desc_fd
-      _debugging
-      _debugging_data
-      _debugging_details
-      _debugging_gory_details
-      _debugging_not_optimized
-      _set_child_debug_name
-    );
-
-    @EXPORT_OK = qw(
-      _debug_init
-      _debugging_level
-      _map_fds
-    );
-    %EXPORT_TAGS = (
-        default => \@EXPORT,
-        all => [ @EXPORT, @EXPORT_OK ],
-    );
+	$VERSION = '0.82';
+	@ISA     = qw( Exporter );
+	@EXPORT  = qw(
+		_debug
+		_debug_desc_fd
+		_debugging
+		_debugging_data
+		_debugging_details
+		_debugging_gory_details
+		_debugging_not_optimized
+		_set_child_debug_name
+	);
+	
+	@EXPORT_OK = qw(
+		_debug_init
+		_debugging_level
+		_map_fds
+	);
+	%EXPORT_TAGS = (
+		default => \@EXPORT,
+		all     => [ @EXPORT, @EXPORT_OK ],
+	);
 }
 
-my $disable_debugging = defined $ENV{IPCRUNDEBUG}
-  && ( !$ENV{IPCRUNDEBUG}
-    || lc $ENV{IPCRUNDEBUG} eq "none" );
+my $disable_debugging =
+   defined $ENV{IPCRUNDEBUG}
+   && (
+      ! $ENV{IPCRUNDEBUG}
+      || lc $ENV{IPCRUNDEBUG} eq "none"
+   );
 
 eval( $disable_debugging ? <<'STUBS' : <<'SUBS' ) or die $@;
 sub _map_fds()                 { "" }
@@ -115,7 +117,8 @@ sub _debugging_not_optimized() { 0 }
 1;
 STUBS
 
-use POSIX ();
+use POSIX;
+use UNIVERSAL qw( isa );
 
 sub _map_fds {
    my $map = '';
@@ -266,7 +269,7 @@ sub _debug_desc_fd {
    my $op = pop;
    my $kid = $_[0];
 
-Carp::carp join " ", caller(0), $text, $op  if defined $op  && UNIVERSAL::isa( $op, "IO::Pty" );
+Carp::carp join " ", caller(0), $text, $op  if defined $op  && isa( $op, "IO::Pty" );
 
    _debug(
       $text,
